/**************************************************************************
/* This class shows faces of all available fonts.
/*
/* Copyright (c) 2003 by Bernhard Bablok (mail@bablokb.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
   This class dumps the names of all available fonts.

   @version $Revision: 1.1 $
   @author  $Author: Bablokb $
*/

public class DisplayFonts extends JFrame {

  private static final String FONT_SIZE = "20";
  private static final Color  FONT_COLOR = Color.black;

  //////////////////////////////////////////////////////////////////////////////

  /**
     Constructor.
  */

  public DisplayFonts() {
  }

  //////////////////////////////////////////////////////////////////////////////

  /**
     Create GUI-components.
  */

  public void createGUI() {
    JPanel panel = new JPanel();
    panel.setLayout(new GridLayout(0,4));
    panel.setBackground(Color.white);
    
    String fontFamilies[] = (new ShowFonts()).getFonts12();
    for (int i=0;i<fontFamilies.length;++i) {
      panel.add(getLabel(fontFamilies[i],"plain",false));
      panel.add(getLabel(fontFamilies[i],"bold",false));
      panel.add(getLabel(fontFamilies[i],"italic",false));
      panel.add(getLabel(fontFamilies[i],"italic",true));
    }
    getContentPane().add(new JScrollPane(panel));
  }

  //////////////////////////////////////////////////////////////////////////////

  /**
     Create a JLabel with specific attributes.
  */
  
  private JLabel getLabel(String fontFamily, String face, boolean antiAlias) {
    String fontName = fontFamily + "-" + face + "-" + FONT_SIZE;
    JLabel label;
    if (antiAlias)
      label = new AntiAliasLabel(fontName);
    else
      label = new JLabel(fontName);
    label.setFont(Font.decode(fontName));
    label.setForeground(FONT_COLOR);
    return label;
  }

  //////////////////////////////////////////////////////////////////////////////

  public static void main(String[] args) {

    DisplayFonts df = new DisplayFonts();

    df.addWindowListener(new WindowAdapter() {
	public void windowClosing(WindowEvent event) {
	  System.exit(0);
	}
      });

    df.createGUI();
    df.setSize(new Dimension(800,600));
    df.setTitle("DisplayFonts");
    df.show();

  }

  //////////////////////////////////////////////////////////////////////////////

  private static class AntiAliasLabel extends JLabel {
    AntiAliasLabel(String fontName) {
      super(fontName);
    }
    public void paintComponent(Graphics g) {
      Graphics2D g2 = (Graphics2D) g;
      ((Graphics2D) g).addRenderingHints(
	new RenderingHints(RenderingHints.KEY_TEXT_ANTIALIASING,
                           RenderingHints.VALUE_TEXT_ANTIALIAS_ON));
      super.paintComponent(g);
    }
  }
}

